@@ -30,11 +30,15 @@ sub description {
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
-    $self->usage_error("This command need two input files.") unless @$args == 2;
-    $self->usage_error("The input file [@{[$args->[0]]}] doesn't exist.")
-        unless -e $args->[0];
-    $self->usage_error("The list file [@{[$args->[1]]}] doesn't exist.")
-        unless -e $args->[1];
+    if ( @{$args} != 2 ) {
+        $self->usage_error("This command need two input files.");
+    }
+    for ( @{$args} ) {
+        next if lc $_ eq "stdin";
+        if ( !Path::Tiny::path($_)->is_file ) {
+            $self->usage_error("The input file [$_] doesn't exist.");
+        }
+    }
 
     if ( !exists $opt->{outfile} ) {
         $opt->{outfile} = Path::Tiny::path( $args->[0] )->absolute . ".list.yml";
