@@ -48,9 +48,15 @@ sub description {
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
-    $self->usage_error("This command need one input file.") unless @$args;
-    $self->usage_error("The input file [@{[$args->[0]]}] doesn't exist.")
-        unless -e $args->[0];
+    if ( @{$args} != 1 ) {
+        $self->usage_error("This command need one input file.");
+    }
+    for ( @{$args} ) {
+        next if lc $_ eq "stdin";
+        if ( !Path::Tiny::path($_)->is_file ) {
+            $self->usage_error("The input file [$_] doesn't exist.");
+        }
+    }
 
     if ( $opt->{op} =~ /^cover/i ) {
         $opt->{op} = 'cover';
